@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.84';
+our $VERSION = '0.85';
 our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
@@ -112,6 +112,8 @@ my $cleanse_mode = 0;
     }
 }
 
+my $approached_openfh_limit;
+
 # open a file handle with (a little) protection
 # against "Too many open files" error.
 # If supported, new file handles are tied to
@@ -150,20 +152,36 @@ sub _safeopen ($*$$;%) {
 	}
     }
 
-    if ($__OPEN_FH > 0.98 * $__MAX_OPEN_FH) {
+    if ($__OPEN_FH > 0.95 * $__MAX_OPEN_FH) {
+        no warnings 'once';
+        my $rescue = 'rescue' eq $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
+	$Forks::Super::Job::Ipc::TOO_MANY_OPEN_FH_WARNINGS++;
         if ($job->{debug}) {
             debug("This program now using $__OPEN_FH of ~$__MAX_OPEN_FH " .
                   "open file handles. Consider closing unused file " .
                   "handles");
-        } else {
-            carp("This program now using $__OPEN_FH of ~$__MAX_OPEN_FH " .
-                  "open file handles. Consider closing unused file " .
-                  "handles");
-        }
-        no warnings 'once';
-	$Forks::Super::Job::Ipc::TOO_MANY_OPEN_FH_WARNINGS++;
+        } elsif (!$approached_openfh_limit++) {
 
-	try_to_close_some_open_filehandles();
+            if (!$rescue && $$ == $Forks::Super::MAIN_PID) {
+                carp("***********************************************\n",
+                     "Forks::Super has determined that this program is\n",
+                     "approaching a system limit on open file handles\n",
+                     "($__OPEN_FH of ~$__MAX_OPEN_FH available).\n",
+                     "Consider closing unused file handles or calling\n",
+                     "Forks::Super::try_to_close_some_open_file handles()\n",
+                     "to let Forks::Super choose which file handles to close.",
+                     "\n\nSee the \"Socket and file handle gotchas\" section\n",
+                     "of the Forks::Super docs for more information.\n",
+                     "***********************************************\n");
+            } else {
+                carp("This program now using $__OPEN_FH of ~$__MAX_OPEN_FH " .
+                     "open file handles. Consider closing unused file " .
+                     "handles");
+            }
+        }
+        return if 'rescue' ne $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
+
+	Forks::Super::try_to_close_some_open_filehandles();
     }
 
 
@@ -311,17 +329,28 @@ sub _handle_safeopen_failure {
 		    "[openfh=$__OPEN_FH/$__MAX_OPEN_FH]. Retrying ...\n";
 	}
     }
-    Forks::Super::pause(0.002 * $try * $try * $try, $try < 3);
+    Forks::Super::pause(0.01 * $try * $try, $try < 3);
     return;
 }
 
-sub try_to_close_some_open_filehandles {
-    {
-        no warnings 'once';
-        return if 'rescue' ne $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
-    }
+my $rescued;
+sub Forks::Super::try_to_close_some_open_filehandles {
     my $nclosed = 0;
 
+    if ($$ == $MAIN_PID && !$rescued++) {
+        carp("*********************************************************\n",
+             "Forks::Super has determined that this program is\n",
+             "approaching the system limit on simultaneous open\n",
+             "file handles, and will attempt to close some\n",
+             "that appear to be unused.\n\n",
+             "Remember to call  Forks::Super::close_fh(\$job)  or\n",
+             "\$job->dispose  when you are doing with I/O operations\n",
+             "on a Forks::Super job.",
+             "\n\nSee the \"Socket and file handle gotchas\" section\n",
+             "of the Forks::Super docs for more information.\n",
+             "*********************************************************\n");
+    }
+
     # in the child, you can close file handles from unrelated jobs ...
     if ($$ != $Forks::Super::MAIN_PID) {
 	use POSIX ();
@@ -343,6 +372,10 @@ sub try_to_close_some_open_filehandles {
 	}
     }
 
+    # close jobs that are
+    #    * done (have a status)
+    #    * old
+
     my @handles_for_finished_jobs =
 	grep { $_->[1]->is_complete } @open_handles;
     @handles_for_finished_jobs = sort {
@@ -370,10 +403,6 @@ sub try_to_close_some_open_filehandles {
 	}
     }
 
-    # close jobs that are
-    #    * old
-    #    * done (have a status)
-
     if ($nclosed) {
 	warn "Forks::Super::Job::Ipc: Closed $nclosed open file handles ",
              "from jobs that look complete.\n";
@@ -3343,7 +3372,7 @@ Forks::Super::Job::Ipc - interprocess communication routines for Forks::Super
 
 =head1 VERSION
 
-0.84
+0.85
 
 =head1 DESCRIPTION
 
